<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta name="description" content="">
        <meta name="author" content="">
        <title>Restclients</title>
        
        <link rel="stylesheet" href="//netdna.bootstrapcdn.com/bootstrap/3.1.1/css/bootstrap.min.css">

        <style type="text/css">
            .restclients-proxy { background: #e5e5e5; margin-bottom: 2em;border-radius: 4px;padding: 5px;}
            .restclients-header { line-height: 30px; margin-bottom:5px;  }
            .restclients-header span.label {  }
            .restclients-header-title { padding-left:20px; font-weight:bold; }
            .restclients-header-url { }
            .restclients-header-url span.glyphicon { font-size: 1.4em; padding: 0 5px; vertical-align: middle; color: #999; }
            .restclients-header-url input { display:inline-block; width: 95%; }
            .restclients-response-content {
                background: #fff; 
                padding: 1em; 
                margin: 0 -5px;
                min-height: 20px;
                background-color: #fff;
                border: 1px solid #e3e3e3;
                border-radius: 0px;
                -webkit-box-shadow: inset 0 1px 1px rgba(0,0,0,0.05);
                box-shadow: inset 0 1px 1px rgba(0,0,0,0.05);
            }
            .restclients-response-content label { font-weight: normal; }
            .restclients-response-content input[type="submit"] { margin: 1em 0; }
            .restclients-response-content ul, .restclients-response-content ol { padding-left: 20px; margin-top: 1em; }
            .restclients-footer { font-size:.85em; }
        </style>

    </head>

    <body>

        {% block content %}{% endblock %}
        {% if has_extra_template %}
            {% include extra_template %}
        {% endif %}

    </body>
</html>
