<div><label for="page_size">Results per page:</label> <select class="page_size" id="page_size" name="page_size">{% if search.page_size %}<option value="{{search.page_size}}" selected="selected">{{search.page_size}}</option>{% endif %}<option value="10">10</option><option value="25">25</option><option value="50">50</option><option value="100">100</option><option value="200">200</option></select></div>
