# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-05-04 21:32
from __future__ import unicode_literals

from django.db import migrations


def empty_cache(apps, schema_editor):
    CacheEntryTimed = apps.get_model('rc_django', 'CacheEntryTimed')
    CacheEntryTimed.objects.all().delete()


class Migration(migrations.Migration):

    dependencies = [
        ('rc_django', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(empty_cache),
    ]
